@@ -5,10 +5,6 @@ aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
 aembit_filter_input_chain_name=aembit_filter_input_chain
 
-aembit_agent_proxy_user_name=aembit_agent_proxy
-aembit_group_id=$(id --group "${aembit_agent_proxy_user_name}")
-azure_platform_resources_ip=168.63.129.16
-
 custom_chains=("raw,OUTPUT,$aembit_raw_output_chain_name" "nat,OUTPUT,$aembit_nat_output_chain_name" "nat,PREROUTING,$aembit_nat_prerouting_chain_name" "filter,INPUT,$aembit_filter_input_chain_name")
 
 for custom_chain in "${custom_chains[@]}"; do
@@ -28,7 +24,3 @@ for custom_chain in "${custom_chains[@]}"; do
     # Delete custom chain
     iptables  -t "$table_name" -X "$custom_chain_name"
 done
-
-# ------ Non custom chains ------
-
-iptables -t security -D OUTPUT -p tcp -d "${azure_platform_resources_ip}" -m owner --gid-owner "${aembit_group_id}" -j ACCEPT
